@@ -21,16 +21,15 @@
 #include "khotkeys.h"
 #include "khotkeys_interface.h"
 
-#include <QDebug>
+#include "kmenuedit_debug.h"
 #include <KLocalizedString>
 #include <KMessageBox>
 
-#include <QDebug>
+#include "kmenuedit_debug.h"
 
 static bool khotkeys_present = false;
 static bool khotkeys_inited = false;
-static OrgKdeKhotkeysInterface *khotkeysInterface = NULL;
-
+static OrgKdeKhotkeysInterface *khotkeysInterface = nullptr;
 
 bool KHotKeys::init()
 {
@@ -44,25 +43,25 @@ bool KHotKeys::init()
         bus,
         NULL);
 
-    if(!khotkeysInterface->isValid()) {
+    if (!khotkeysInterface->isValid()) {
         QDBusError err = khotkeysInterface->lastError();
         if (err.isValid()) {
-            qCritical() << err.name() << ":" << err.message();
+            qCCritical(KMENUEDIT_LOG) << err.name() << ":" << err.message();
         }
         KMessageBox::error(
             NULL,
-            "<qt>" + i18n("Unable to contact khotkeys. Your changes are saved, but they could not be activated.") + "</qt>" );
+            QStringLiteral("<qt>") + i18n("Unable to contact khotkeys. Your changes are saved, but they could not be activated.") + QStringLiteral("</qt>"));
     }
 
     khotkeys_present = khotkeysInterface->isValid();
 
-    qDebug() << khotkeys_present;
+    qCDebug(KMENUEDIT_LOG) << khotkeys_present;
     return true;
 }
 
 void KHotKeys::cleanup()
 {
-    if( khotkeys_inited && khotkeys_present ) {
+    if (khotkeys_inited && khotkeys_present) {
         // CleanUp ???
     }
 
@@ -71,62 +70,64 @@ void KHotKeys::cleanup()
 
 bool KHotKeys::present()
 {
-qDebug() << khotkeys_inited;
+    qCDebug(KMENUEDIT_LOG) << khotkeys_inited;
 
-    if( !khotkeys_inited )
+    if (!khotkeys_inited) {
         init();
+    }
 
-    qDebug() << khotkeys_present;
+    qCDebug(KMENUEDIT_LOG) << khotkeys_present;
 
     return khotkeys_present;
 }
 
-QString KHotKeys::getMenuEntryShortcut( const QString& entry_P )
+QString KHotKeys::getMenuEntryShortcut(const QString &entry_P)
 {
-    if( !khotkeys_inited )
+    if (!khotkeys_inited) {
         init();
+    }
 
-    if( !khotkeys_present || !khotkeysInterface->isValid())
+    if (!khotkeys_present || !khotkeysInterface->isValid()) {
         return QLatin1String("");
-qDebug() << khotkeys_inited;
-    qDebug() << khotkeys_present;
-    qDebug() << entry_P;
+    }
+    qCDebug(KMENUEDIT_LOG) << khotkeys_inited;
+    qCDebug(KMENUEDIT_LOG) << khotkeys_present;
+    qCDebug(KMENUEDIT_LOG) << entry_P;
     QDBusReply<QString> reply = khotkeysInterface->get_menuentry_shortcut(entry_P);
     if (!reply.isValid()) {
-        qCritical() << reply.error();
+        qCCritical(KMENUEDIT_LOG) << reply.error();
         return QLatin1String("");
-
     } else {
-            qDebug() << reply;
+        qCDebug(KMENUEDIT_LOG) << reply;
         return reply;
     }
 }
 
 QString KHotKeys::changeMenuEntryShortcut(
-        const QString& entry_P,
-        const QString shortcut_P )
+    const QString &entry_P, const QString shortcut_P)
 {
-    if( !khotkeys_inited )
+    if (!khotkeys_inited) {
         init();
+    }
 
-    if( !khotkeys_present || !khotkeysInterface->isValid())
+    if (!khotkeys_present || !khotkeysInterface->isValid()) {
         return QLatin1String("");
+    }
 
-    qDebug() << khotkeys_inited;
-    qDebug() << khotkeys_present;
-    qDebug() << entry_P;
-    qDebug() << shortcut_P;
+    qCDebug(KMENUEDIT_LOG) << khotkeys_inited;
+    qCDebug(KMENUEDIT_LOG) << khotkeys_present;
+    qCDebug(KMENUEDIT_LOG) << entry_P;
+    qCDebug(KMENUEDIT_LOG) << shortcut_P;
 
     QDBusReply<QString> reply = khotkeysInterface->register_menuentry_shortcut(
-            entry_P,
-            shortcut_P);
+        entry_P,
+        shortcut_P);
 
     if (!reply.isValid()) {
-        qCritical() << reply.error();
+        qCCritical(KMENUEDIT_LOG) << reply.error();
         return QLatin1String("");
     } else {
-        qDebug() << reply;
+        qCDebug(KMENUEDIT_LOG) << reply;
         return reply;
     }
 }
-
